{
  description = "Jimbo's systems as a flake";

  inputs = {
    # Nixpkgs
    nixpkgs.url = "github:nixos/nixpkgs/nixos-24.05";
    nixpkgs-unstable.url = "github:nixos/nixpkgs/nixos-unstable";
    nur.url = "github:nix-community/NUR";
    nixos-mailserver.url = "gitlab:simple-nixos-mailserver/nixos-mailserver/nixos-24.05";
    blender-bin.url = "https://flakehub.com/f/edolstra/blender-bin/1.0.8.tar.gz";
    nix-minecraft.url = "github:Infinidoge/nix-minecraft";
    jovian-nixos.url = "github:Jovian-Experiments/Jovian-NixOS";
    hardware.url = "github:nixos/nixos-hardware/master";

    # Home manager
    home-manager = {
      url = "github:nix-community/home-manager/release-24.05";
      inputs.nixpkgs.follows = "nixpkgs";
    };

    # Home manager unstable
    home-manager-unstable = {
      url = "https://github.com/nix-community/home-manager/archive/master.tar.gz";
      inputs.nixpkgs.follows = "nixpkgs";
    };
  };

  outputs = {
    self,
    nixpkgs,
    nixpkgs-unstable,
    nur,
    nixos-mailserver,
    blender-bin,
    jovian-nixos,
    home-manager,
    home-manager-unstable,
    ...
  } @inputs: let
    inherit (self) outputs;
    forAllSystems = nixpkgs.lib.genAttrs [
      "aarch64-linux" 
      "x86_64-linux"
    ];
  in rec {
    # Your custom packages
    # Accessible through 'nix build', 'nix shell', etc
    packages = forAllSystems (system: import ./pkgs nixpkgs.legacyPackages.${system});

    # Your custom packages and modifications, exported as overlays
    overlays = import ./overlays {inherit inputs;};

    # Secrets defined so they can be accessed globally
    secrets = import ./secrets.nix;

    # NixOS configuration entrypoint, use 'nixos-rebuild --flake .#your-hostname'
    nixosConfigurations = {
      JimDesktop = nixpkgs.lib.nixosSystem {
        specialArgs = {inherit inputs outputs;};
        modules = [
          ./nixos/desktop.nix
        ];
      };
      JimServer = nixpkgs.lib.nixosSystem {
        specialArgs = {inherit inputs outputs;};
        modules = [
          ./nixos/server.nix
	  nixos-mailserver.nixosModule
        ];
      };
      JimDeck = nixpkgs-unstable.lib.nixosSystem {
        specialArgs = {inherit inputs outputs;};
        modules = [
          ./nixos/deck.nix
          jovian-nixos.nixosModules.default
        ];
      };
    };

    # Standalone home-manager configuration
    # Available through 'home-manager --flake .#your-username@your-hostname'
    homeConfigurations = {
      "jimbo@JimDesktop" = home-manager.lib.homeManagerConfiguration {
        pkgs = nixpkgs.legacyPackages.x86_64-linux;
        extraSpecialArgs = {inherit inputs outputs;};
        modules = [
          ./home-manager/jimbo_desktop.nix
	  nur.nixosModules.nur
        ];
      };
      "jimbo@JimServer" = home-manager.lib.homeManagerConfiguration {
        pkgs = nixpkgs.legacyPackages.x86_64-linux;
        extraSpecialArgs = {inherit inputs outputs;};
        modules = [
          ./home-manager/jimbo_server.nix
        ];
      };
      "jimbo@JimDeck" = home-manager.lib.homeManagerConfiguration {
        pkgs = nixpkgs.legacyPackages.x86_64-linux;
        extraSpecialArgs = {inherit inputs outputs;};
        modules = [
          ./home-manager/jimbo_deck.nix
	  nur.nixosModules.nur
        ];
      };
      # Derivation for ssh envrionments on other people's servers
      "jimbo@SSH" = home-manager.lib.homeManagerConfiguration {
        pkgs = nixpkgs.legacyPackages.x86_64-linux;
        extraSpecialArgs = {inherit inputs outputs;};
        modules = [
          ./home-manager/jimbo_ssh.nix
        ];
      };
    };
  };
}
